/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.sqladmin.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * A Google Cloud SQL service tier resource.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Cloud SQL Administration API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Tier extends GenericJson {

  /**
   * The maximum disk size of this tier in bytes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("DiskQuota") @JsonString
  private Long diskQuota;

  /**
   * The maximum RAM usage of this tier in bytes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("RAM") @JsonString
  private Long rAM;

  /**
   * This is always sql#tier.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The applicable regions for this tier. Can be us-east1 and europe-west1.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> region;

  /**
   * An identifier for the service tier, for example D1, D2 etc. For related information, see
   * Pricing.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String tier;

  /**
   * The maximum disk size of this tier in bytes.
   * The value returned may be {@code null}.
   */
  public Long getDiskQuota() {
    return diskQuota;
  }

  /**
   * The maximum disk size of this tier in bytes.
   * The value set may be {@code null}.
   */
  public Tier setDiskQuota(Long diskQuota) {
    this.diskQuota = diskQuota;
    return this;
  }

  /**
   * The maximum RAM usage of this tier in bytes.
   * The value returned may be {@code null}.
   */
  public Long getRAM() {
    return rAM;
  }

  /**
   * The maximum RAM usage of this tier in bytes.
   * The value set may be {@code null}.
   */
  public Tier setRAM(Long rAM) {
    this.rAM = rAM;
    return this;
  }

  /**
   * This is always sql#tier.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * This is always sql#tier.
   * The value set may be {@code null}.
   */
  public Tier setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The applicable regions for this tier. Can be us-east1 and europe-west1.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getRegion() {
    return region;
  }

  /**
   * The applicable regions for this tier. Can be us-east1 and europe-west1.
   * The value set may be {@code null}.
   */
  public Tier setRegion(java.util.List<String> region) {
    this.region = region;
    return this;
  }

  /**
   * An identifier for the service tier, for example D1, D2 etc. For related information, see
   * Pricing.
   * The value returned may be {@code null}.
   */
  public String getTier() {
    return tier;
  }

  /**
   * An identifier for the service tier, for example D1, D2 etc. For related information, see
   * Pricing.
   * The value set may be {@code null}.
   */
  public Tier setTier(String tier) {
    this.tier = tier;
    return this;
  }

}
